{% extends 'spectator_events/base.html' %}

{% load spectator_core %}

{% block head_page_title %}{% if event_kind_name_plural %}{{ event_kind_name_plural }}{% else %}Events{% endif %}{% if page_obj.number > 1 %} page {{ page_obj.number }}{% endif %}{% endblock %}
{% block content_title %}Events{% endblock %}

{% load spectator_events %}

{% block breadcrumbs %}
	{% if event_kind %}
		{{ block.super }}
	{% else %}
		<li class="breadcrumb-item"><a href="{% url 'spectator:core:home' %}">Home</a></li>
		<li class="breadcrumb-item active">Events</li>
	{% endif %}

{% endblock %}

{% block content %}

    {% if event_list|length > 0 %}
			{% event_list_tabs counts event_kind page_obj.number %}
    {% endif %}

    {% include 'spectator_events/includes/events_paginated.html' with event_list=event_list page_obj=page_obj only %}

{% endblock content %}
