{% extends 'spectator_core/base.html' %}

{% load spectator_core spectator_reading %}

{% block reading_nav_active %}active{% endblock %}

{% block breadcrumbs %}
    {{ block.super }}
    <li class="breadcrumb-item"><a href="{% url 'spectator:reading:home' %}">Reading</a></li>
{% endblock %}


{% block sidebar %}

    {% include 'spectator_reading/includes/card_nav.html' %}
    {% include 'spectator_core/includes/card_nav.html' %}

    {% current_url_name as url_name %}

    {% if url_name != 'spectator:reading:home' and url_name != 'spectator:reading:reading_year_archive' %}
        {% in_progress_publications_card %}
    {% endif %}

    {% reading_years_card current_year=year %}

{% endblock sidebar %}
